@@ -459,6 +459,10 @@ try:
     library.MagickTrimImage.argtypes = [ctypes.c_void_p,
                                         ctypes.c_double]
 
+    library.MagickGaussianBlurImage.argtypes = [ctypes.c_void_p,
+                                                ctypes.c_double,
+                                                ctypes.c_double]
+
     library.MagickGetNumberImages.argtypes = [ctypes.c_void_p]
     library.MagickGetNumberImages.restype = ctypes.c_size_t
 
@@ -597,6 +601,12 @@ try:
     library.DrawSetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawSetStrokeColor.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_void_p]
+
+    library.DrawSetStrokeWidth.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_double]
+
     library.DrawSetTextAlignment.argtypes = [ctypes.c_void_p,
                                              ctypes.c_int]
 
@@ -609,8 +619,11 @@ try:
     library.DrawSetTextEncoding.argtypes = [ctypes.c_void_p,
                                             ctypes.c_char_p]
 
-    library.DrawSetTextInterlineSpacing.argtypes = [ctypes.c_void_p,
-                                                    ctypes.c_double]
+    try:
+        library.DrawSetTextInterlineSpacing.argtypes = [ctypes.c_void_p,
+                                                        ctypes.c_double]
+    except AttributeError:
+        library.DrawSetTextInterlineSpacing = None
 
     library.DrawSetTextInterwordSpacing.argtypes = [ctypes.c_void_p,
                                                     ctypes.c_double]
@@ -624,6 +637,12 @@ try:
     library.DrawGetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawGetStrokeColor.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_void_p]
+
+    library.DrawGetStrokeWidth.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeWidth.restype = ctypes.c_double
+
     library.DrawGetFont.argtypes = [ctypes.c_void_p]
     library.DrawGetFont.restype = ctypes.c_char_p
 
@@ -642,8 +661,11 @@ try:
     library.DrawGetTextEncoding.argtypes = [ctypes.c_void_p]
     library.DrawGetTextEncoding.restype = ctypes.c_char_p
 
-    library.DrawGetTextInterlineSpacing.argtypes = [ctypes.c_void_p]
-    library.DrawGetTextInterlineSpacing.restype = ctypes.c_double
+    try:
+        library.DrawGetTextInterlineSpacing.argtypes = [ctypes.c_void_p]
+        library.DrawGetTextInterlineSpacing.restype = ctypes.c_double
+    except AttributeError:
+        library.DrawGetTextInterlineSpacing = None
 
     library.DrawGetTextInterwordSpacing.argtypes = [ctypes.c_void_p]
     library.DrawGetTextInterwordSpacing.restype = ctypes.c_double
