@@ -19,7 +19,8 @@ import weakref
 from . import compat
 from .api import MagickPixelPacket, libc, libmagick, library
 from .color import Color
-from .compat import binary, binary_type, file_types, string_type, text, xrange
+from .compat import (binary, binary_type, encode_filename, file_types,
+                     string_type, text, xrange)
 from .exceptions import WandException
 from .resource import DestroyedResourceError, Resource
 from .font import Font
@@ -1525,6 +1526,31 @@ class BaseImage(Resource):
                                             op, int(left), int(top))
         self.raise_exception()
 
+    @manipulative
+    def gaussian_blur(self, radius, sigma):
+        """Blurs the image.  We convolve the image with a gaussian operator
+        of the given ``radius`` and standard deviation (``sigma``).
+        For reasonable results, the ``radius`` should be larger
+        than ``sigma``.  Use a ``radius`` of 0 and :meth:`blur()` selects
+        a suitable ``radius`` for you.
+
+        :param radius: the radius of the, in pixels,
+                       not counting the center pixel
+        :type radius: :class:`numbers.Real`
+        :param sigma: the standard deviation of the, in pixels
+        :type sigma: :class:`numbers.Real`
+
+        """
+        if not isinstance(radius, numbers.Real):
+            raise TypeError('radius has to be a numbers.Real, not ' +
+                            repr(radius))
+        elif not isinstance(sigma, numbers.Real):
+            raise TypeError('sigma has to be a numbers.Real, not ' +
+                            repr(sigma))
+        r = library.MagickGaussianBlurImage(self.wand, radius, sigma)
+        if not r:
+            self.raise_exception()
+
     @manipulative
     def watermark(self, image, transparency=0.0, left=0, top=0):
         """Transparentized the supplied ``image`` and places it over the
@@ -1749,7 +1775,8 @@ class Image(BaseImage):
                 blob = b''.join(blob)
             r = library.MagickReadImageBlob(self.wand, blob, len(blob))
         elif filename is not None:
-            r = library.MagickReadImage(self.wand, binary(filename))
+            filename = encode_filename(filename)
+            r = library.MagickReadImage(self.wand, filename)
         if not r:
             self.raise_exception()
 
@@ -1911,6 +1938,7 @@ class Image(BaseImage):
             if isinstance(file, file_types) and hasattr(libc, 'fdopen'):
                 fd = libc.fdopen(file.fileno(), file.mode)
                 r = library.MagickWriteImageFile(self.wand, fd)
+                libc.fflush(fd)
                 if not r:
                     self.raise_exception()
             else:
@@ -1923,7 +1951,7 @@ class Image(BaseImage):
             if not isinstance(filename, string_type):
                 raise TypeError('filename must be a string, not ' +
                                 repr(filename))
-            filename = binary(filename)
+            filename = encode_filename(filename)
             if len(self.sequence) > 1:
                 r = library.MagickWriteImages(self.wand, filename, True)
             else:
@@ -2257,7 +2285,7 @@ class Metadata(ImageProperty, collections.Mapping):
         """
         image = self.image
         if not isinstance(k, string_type):
-            raise TypeError('k must be a string, not ' + repr(format))
+            raise TypeError('k must be a string, not ' + repr(k))
         v = library.MagickGetImageProperty(image.wand, binary(k))
         if bool(v) is False:
             raise KeyError(k)
@@ -2268,7 +2296,7 @@ class Metadata(ImageProperty, collections.Mapping):
         image = self.image
         num = ctypes.c_size_t()
         props_p = library.MagickGetImageProperties(image.wand, b'', num)
-        props = [props_p[i] for i in xrange(num.value)]
+        props = [text(props_p[i]) for i in xrange(num.value)]
         library.MagickRelinquishMemory(props_p)
         return iter(props)
 
